/* vbiinfo - Dump V4L2 VBI device parameters
 *
 * phil@sanslogic.co.uk
*/

#include <stdint.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <linux/videodev2.h>

int main(int argc, char *argv[])
{
	int r;
	int fd;
	struct v4l2_format fmt;
	
	if(argc != 2)
	{
		printf("Usage: vbiinfo </dev/vbiX>\n");
		return(-1);
	}
	
	fd = open(argv[1], 0);
	if(fd < 0)
	{
		perror("open");
		return(-1);
	}
	
	/* Query the device configuration */
	memset(&fmt, 0, sizeof(struct v4l2_format));
	fmt.type = V4L2_BUF_TYPE_VBI_CAPTURE;
	r = ioctl(fd, VIDIOC_G_FMT, &fmt);
	if(r < 0)
	{
		perror("ioctl");
		close(fd);
		return(-1);
	}
	
	printf("/* VBI device config:\n");
	printf("\tsampling_rate:    %d\n", fmt.fmt.vbi.sampling_rate);
	printf("\toffset:           %d\n", fmt.fmt.vbi.offset);
	printf("\tsamples_per_line: %d\n", fmt.fmt.vbi.samples_per_line);
	printf("\tsample_format:    %d\n", fmt.fmt.vbi.sample_format);
	printf("\tstart[2]:         %d, %d\n", fmt.fmt.vbi.start[0], fmt.fmt.vbi.start[1]);
	printf("\tcount[2]:         %d, %d\n", fmt.fmt.vbi.count[0], fmt.fmt.vbi.count[1]);
	printf("\tflags:            %d\n", fmt.fmt.vbi.flags);
	printf("*/\n");
	
	close(fd);
	
	return(0);
}

